@@ -1,4 +1,6 @@
 "A collection of readonly immutables"
+from copy import deepcopy
+
 from supermutes.utils import get_new_obj, get_class_registrar
 
 CLASS_REGISTER = {}
@@ -34,6 +36,17 @@ class ReadOnlyList(ReadOnlyBaseClass, list):
     def __getitem__(self, index):
         return readonly(list.__getitem__(self, index))
 
+    def get_writable(self):
+        "Get a fully writable version of this list"
+        writable = list([])
+        for item in self:
+            try:
+                item = item.get_writable()
+            except AttributeError:
+                pass
+            writable.append(item)
+        return deepcopy(writable)
+
 
 class ReadOnlyDict(ReadOnlyBaseClass, dict):
 
@@ -42,5 +55,15 @@ class ReadOnlyDict(ReadOnlyBaseClass, dict):
     def __getitem__(self, key):
         return readonly(dict.__getitem__(self, key))
 
+    def get_writable(self):
+        "Get a fully writable version of this dictionary"
+        writable = dict({})
+        for key, item in self.items():
+            try:
+                item = item.get_writable()
+            except AttributeError:
+                pass
+            writable[key] = item
+        return deepcopy(writable)
 
 reset_mapping()
